@@ -101,8 +101,8 @@ class ChatAnalyser:
         self.exp_mov_avg = []
         self.highlight_annotation = []
         self.highlights = []
+        self.contexts = []
 
-        self.contexts = list[Context]
         self.source = ContextSourceManager() # important
         if self.default_context_path:
             self.source.add(self.default_context_path)
@@ -123,7 +123,7 @@ class ChatAnalyser:
         """Checks context compitability. Tries to autofix collisions if possible."""
 
         self.logger.info("Checking contexts")
-        self.logger.debug(f"{autofix=}")
+        self.logger.debug(f"autofix={autofix}")
         
         # TODO check triggers too (right now it only checks reactions)
         seen_tuples = set()
@@ -152,8 +152,8 @@ class ChatAnalyser:
                     i = next((i for i, nc in enumerate(new_contexts) if nc['reaction_to'] == context['reaction_to']), None)
                     if i == None:
                         self.logger.critical(f"Unexpected error: i={i}")
-                        self.logger.critical(f"{new_contexts=}")
-                        self.logger.critical(f"{context=}")
+                        self.logger.critical(f"new_contexts={new_contexts}")
+                        self.logger.critical(f"context={context}")
                         raise UnexpectedException("You should not be seeing this.")
                     new_contexts[i].get('triggers').extend(context.get('triggers'))
                 else:
@@ -165,7 +165,7 @@ class ChatAnalyser:
                     )
         self.contexts = new_contexts
 
-    def parse_contexts(self, autofix:bool=False) -> list[Context]:
+    def parse_contexts(self, autofix:bool=False) -> list:
         """Parses the contexts from dictionary to dataclass format"""
 
         self.logger.info("Parsing contexts")
@@ -198,7 +198,7 @@ class ChatAnalyser:
             )
         return parsed_contexts
 
-    def get_contexts(self, autofix:bool=False) -> list[Context]:
+    def get_contexts(self, autofix:bool=False) -> list:
         """Wrapper function to get the contexts"""
         self.read_contexts_from_sources()
         self._check_contexts(autofix=autofix)
@@ -242,7 +242,7 @@ class ChatAnalyser:
 
         return self.frequency
 
-    def init_intensity(self, levels=[], constants=[], colors=[]) -> list[Intensity]:
+    def init_intensity(self, levels=[], constants=[], colors=[]) -> list:
         """Returns list of intensity which will be used for
             measuring how tense was the highlight. Leave empty
             for default values.
@@ -262,9 +262,9 @@ class ChatAnalyser:
         """
 
         self.logger.info("Initializing intensity")
-        self.logger.debug(f"{levels=}")
-        self.logger.debug(f"{constants=}")
-        self.logger.debug(f"{colors=}")
+        self.logger.debug(f"levels={levels}")
+        self.logger.debug(f"constants={constants}")
+        self.logger.debug(f"colors={colors}")
 
         levels = levels or ["medium", "high", "very high", "ultra high"]
         constants = constants or [0, 0.7, 1.4, 2.1]
@@ -308,16 +308,16 @@ class ChatAnalyser:
             print(f"Calculating moving average... done")
         return self.fre_mov_avg
 
-    def _smoothen(self, dict, w=40) -> list[np.ndarray]:
+    def _smoothen(self, dict, w=40) -> list:
         return list(np.convolve(list(dict.values()), np.ones(w) / w, mode="same"))
 
-    def smoothen_mov_avg(self) -> list[np.ndarray]:
+    def smoothen_mov_avg(self) -> list:
         self.exp_mov_avg = self._smoothen(self.fre_mov_avg)
         return self.exp_mov_avg
 
-    def create_highlight_annotation(self) -> list[int]:
+    def create_highlight_annotation(self) -> list:
         """Creates highlight annotation from moving average.
-        Values are either -1, 0 or 1 where 1 means it's increasing."""
+        Values are either -1, 0 or 1 where 1 means the value increasing."""
 
         self.logger.info("Creating highlight annotation")
         self.highlight_annotation = []
@@ -341,7 +341,7 @@ class ChatAnalyser:
 
         return self.highlight_annotation
 
-    def line_colors(self) -> list[str]:
+    def line_colors(self) -> list:
         """Sets plot colors according to highlight annotation"""
 
         self.logger.info("Setting line colors")
@@ -356,16 +356,11 @@ class ChatAnalyser:
                 colors.append("gray")
         return colors
 
-    def detect_highlight_times(self) -> list[Highlight]:
+    def detect_highlight_times(self) -> list:
         """Detects highlight times and durations according to highlight annotation and
             smoothened moving average.  Also sets frequency delta, which is the change
             of frequency within highlight duration.
 
-        Args:
-            highlight_annotation (list[int]): Highlight annotation returned from
-                create_highlight_annotation method.
-            exp_mov_avg (list): Smoothened values of moving average of message frequency.
-            min_duration (int): Minimum highlight duration to detect.
         Returns:
             list[Highlight]: List of highlight times
         """
@@ -412,7 +407,7 @@ class ChatAnalyser:
             print("Detecting highlight timestamps... done")
         return self.highlights
 
-    def correct_highlights(self) -> list[Highlight]:
+    def correct_highlights(self) -> list:
         """Corrects highlights by removing highlights that are too short or filtered"""
 
         # TODO consider fdelta too
@@ -443,7 +438,7 @@ class ChatAnalyser:
             print("Correcting highlights... done")
         return self.highlights
 
-    def set_highlight_intensities(self) -> list[Highlight]:
+    def set_highlight_intensities(self) -> list:
         """Sets highlight intensities based on frequency delta"""
 
         if not self.highlights:
@@ -467,7 +462,7 @@ class ChatAnalyser:
             print("Setting highlight intensities... done")
         return self.highlights
 
-    def get_highlight_messages(self) -> list[Highlight]:
+    def get_highlight_messages(self) -> list:
         """Gets messages typed during highlights"""
 
         self.logger.info("Getting highlight messages")
@@ -504,7 +499,7 @@ class ChatAnalyser:
         return self.highlights
 
     @staticmethod
-    def get_keyword_emotes(highlight:Highlight) -> set[Emote]:
+    def get_keyword_emotes(highlight:Highlight) -> set:
         emotes = set()
         for msg in highlight.messages:
             for emote in msg.emotes:
@@ -512,12 +507,10 @@ class ChatAnalyser:
                     emotes.add(emote)
         return emotes
 
-    def get_highlight_keywords(self) -> list[Highlight]:
-        """
-        Adds most frequently used words to the highlight list."""
-        print()
-        print("Warning: `get_highlight_keywords` is deprecated, use `get_highlight_keyphrases` instead")
-        print()
+    def get_highlight_keywords(self) -> list:
+        """Adds most frequently used words to the highlight list"""
+
+        print("\nWarning: `get_highlight_keywords` is deprecated, use `get_highlight_keyphrases` instead\n")
 
         self.logger.info("Getting keywords (old function)")
 
@@ -571,7 +564,7 @@ class ChatAnalyser:
             print("Getting highlight keywords... done")
         return self.highlights
 
-    def get_highlight_keyphrases(self) -> list[Highlight]:
+    def get_highlight_keyphrases(self) -> list:
         """Adds most frequently used phrases to the highlight list."""
 
         self.logger.info("Getting keyphrases")
@@ -634,7 +627,7 @@ class ChatAnalyser:
     def _is_keyword_emote(self, keyword):
         return keyword.startswith(':') and keyword.endswith(':')
 
-    def guess_context(self) -> list[str]:
+    def guess_context(self) -> list:
         """Guesses context by looking up the keywords for each highlight."""
 
         self.logger.info("Guessing context")
@@ -664,7 +657,7 @@ class ChatAnalyser:
             print(f"Guessing contexts... done")
         return self.highlights
 
-    def get_highlights(self, autofix_context_collision:bool=False) -> list[Highlight]:
+    def get_highlights(self, autofix_context_collision:bool=False) -> list:
         """Returns a filled highlight list."""
 
         self.detect_highlight_times()
