@@ -72,7 +72,6 @@ class FileHandler:
             level=def_level,
             format=format,
             filename=os.path.join(self.log_path, self._get_logname()),
-            encoding="utf-8",
         )
         console = logging.StreamHandler()
         console.setLevel(def_level)
@@ -234,8 +233,8 @@ class FileHandler:
         """
 
         self.logger.info("Clearing cache")
-        self.logger.debug(f"{cache_deletion_algorithm=}")
-        self.logger.debug(f"{delete_root_folder=}")
+        self.logger.debug(f"cache_deletion_algorithm={cache_deletion_algorithm}")
+        self.logger.debug(f"delete_root_folder={delete_root_folder}")
 
         if not cache_deletion_algorithm:
             if self.sid_path:
@@ -292,8 +291,8 @@ class FileHandler:
         """
 
         self.logger.info("Checking cache integrity")
-        self.logger.debug(f"{cache_path=}")
-        self.logger.debug(f"{autofix=}")
+        self.logger.debug(f"cache_path={cache_path}")
+        self.logger.debug(f"autofix={autofix}")
 
         if not cache_path:
             cache_path = self.sid_path
@@ -306,8 +305,8 @@ class FileHandler:
         unnecesary_files = list(set(files) - set(necessary_files))
         missing_files = list(set(necessary_files) - set(files))
 
-        self.logger.debug(f"{unnecesary_files=}")
-        self.logger.debug(f"{missing_files=}")
+        self.logger.debug(f"unnecesary_files={unnecesary_files}")
+        self.logger.debug(f"missing_files={missing_files}")
 
         if autofix:
             for folder in os.listdir(self.cache_path):
@@ -330,7 +329,7 @@ class FileHandler:
 
         return missing_files, unnecesary_files
 
-    def get_filenames(self, path, show_extension=False) -> list[str]:
+    def get_filenames(self, path, show_extension=False):
         """Returns file names in a path"""
 
         self.logger.info(f"Finding file names in {path}")
@@ -345,7 +344,7 @@ class FileHandler:
         except Exception as e:
             self.logger.error(e)
 
-    def get_foldernames(self, path) -> list[str]:
+    def get_foldernames(self, path):
         """Returns folder names in a path"""
 
         self.logger.info(f"Finding folder names in {path}")
@@ -355,7 +354,7 @@ class FileHandler:
             self.logger.error(e)
             raise e
 
-    def _creation_time_in_days(self, path) -> int:
+    def _creation_time_in_days(self, path):
         """Returns difference between the creation time and
         the current time of the file in days"""
 
@@ -490,7 +489,7 @@ class FileHandler:
         """Returns False if all necessary files are absent"""
 
         self.logger.info("Checking if cached")
-        self.logger.debug(f"{sid=}")
+        self.logger.debug(f"sid={sid}")
 
         if sid:
             path = os.path.join(self.cache_path, sid)
@@ -507,7 +506,7 @@ class FileHandler:
         self.logger.debug(f"is_cached: {(not len(missing_files) == 2)}")
         return not len(missing_files) == 2
 
-    def get_cached_ids(self) -> list[str]:
+    def get_cached_ids(self) -> list:
         """Returns list of cached ids"""
         return [f for f in self.get_foldernames(self.cache_path) if self.is_cached(f)]
 
@@ -526,8 +525,8 @@ class FileHandler:
                 example: `[{phrase:"lol", is_exact:False}]`
         """
         self.logger.info("Adding new context")
-        self.logger.debug(f"{reaction_to=}")
-        self.logger.debug(f"{phrases=}")
+        self.logger.debug(f"reaction_to={reaction_to}")
+        self.logger.debug(f"phrases={phrases}")
 
         new_context = {
             "reaction_to": reaction_to,
@@ -548,7 +547,7 @@ class FileHandler:
             reaction_to (str): Reaction to be deleted.
         """
         self.logger.info("Removing context")
-        self.logger.debug(f"{reaction_to=}")
+        self.logger.debug(f"reaction_to={reaction_to}")
 
         with open(CONTEXT_PATH, "r", encoding="utf-8") as file:
             contexts = list(json.load(file))
